# coding=utf-8
from fabric.api import task
from .utils import jsonprint
from .utils import request

@task
def allocation_explain(*args, **kwargs):
    res = request("allocation_explain", "cluster", *args, **kwargs)
    jsonprint(res)
    return res

@task
def get_settings(*args, **kwargs):
    res = request("get_settings", "cluster", *args, **kwargs)
    jsonprint(res)
    return res

@task
def health(*args, **kwargs):
    res = request("health", "cluster", *args, **kwargs)
    jsonprint(res)
    return res

@task
def pending_tasks(*args, **kwargs):
    res = request("pending_tasks", "cluster", *args, **kwargs)
    jsonprint(res)
    return res

@task
def put_settings(*args, **kwargs):
    res = request("put_settings", "cluster", *args, **kwargs)
    jsonprint(res)
    return res

@task
def reroute(*args, **kwargs):
    res = request("reroute", "cluster", *args, **kwargs)
    jsonprint(res)
    return res

@task
def state(*args, **kwargs):
    res = request("state", "cluster", *args, **kwargs)
    jsonprint(res)
    return res

@task
def stats(*args, **kwargs):
    res = request("stats", "cluster", *args, **kwargs)
    jsonprint(res)
    return res



# coding=utf-8
import os
import json

from elasticsearch import Elasticsearch
from fabric.api import env
from fabric.api import task
from .utils import jsonprint
from .utils import request

import cat
import cluster
import helpers
import indices
import nodes


env.elasticsearch_alias = "default"
env.elasticsearch_dest_alias = "default"
env.elasticsearch_clients = {
    "default": Elasticsearch(**{
        "send_get_body_as": "POST"
    })
}


@task(alias="c")
def client_selection(alias="default", dest=None):
    env.elasticsearch_alias = alias
    env.elasticsearch_dest_alias = dest
    if dest is None:
        env.elasticsearch_dest_alias = env.elasticsearch_alias

@task
def bulk(*args, **kwargs):
    res = request("bulk", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def clear_scroll(*args, **kwargs):
    res = request("clear_scroll", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def count(*args, **kwargs):
    res = request("count", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def count_percolate(*args, **kwargs):
    res = request("count_percolate", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def create(*args, **kwargs):
    res = request("create", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def delete(*args, **kwargs):
    res = request("delete", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def delete_by_query(*args, **kwargs):
    res = request("delete_by_query", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def delete_script(*args, **kwargs):
    res = request("delete_script", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def delete_template(*args, **kwargs):
    res = request("delete_template", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def exists(*args, **kwargs):
    res = request("exists", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def explain(*args, **kwargs):
    res = request("explain", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def field_stats(*args, **kwargs):
    res = request("field_stats", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def get(*args, **kwargs):
    res = request("get", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def get_script(*args, **kwargs):
    res = request("get_script", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def get_source(*args, **kwargs):
    res = request("get_source", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def get_template(*args, **kwargs):
    res = request("get_template", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def index(*args, **kwargs):
    res = request("index", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def info(*args, **kwargs):
    res = request("info", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def mget(*args, **kwargs):
    res = request("mget", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def mpercolate(*args, **kwargs):
    res = request("mpercolate", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def msearch(*args, **kwargs):
    res = request("msearch", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def msearch_template(*args, **kwargs):
    res = request("msearch_template", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def mtermvectors(*args, **kwargs):
    res = request("mtermvectors", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def percolate(*args, **kwargs):
    res = request("percolate", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def ping(*args, **kwargs):
    res = request("ping", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def put_script(*args, **kwargs):
    res = request("put_script", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def put_template(*args, **kwargs):
    res = request("put_template", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def reindex(*args, **kwargs):
    res = request("reindex", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def reindex_rethrottle(*args, **kwargs):
    res = request("reindex_rethrottle", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def render_search_template(*args, **kwargs):
    res = request("render_search_template", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def scroll(*args, **kwargs):
    res = request("scroll", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def search(*args, **kwargs):
    res = request("search", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def search_shards(*args, **kwargs):
    res = request("search_shards", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def search_template(*args, **kwargs):
    res = request("search_template", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def suggest(*args, **kwargs):
    res = request("suggest", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def termvectors(*args, **kwargs):
    res = request("termvectors", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def update(*args, **kwargs):
    res = request("update", None, *args, **kwargs)
    jsonprint(res)
    return res

@task
def update_by_query(*args, **kwargs):
    res = request("update_by_query", None, *args, **kwargs)
    jsonprint(res)
    return res



# coding=utf-8
import sys
import json
from fabric.api import *
from elasticsearch import Elasticsearch
from elasticsearch import helpers
from .utils import jsonprint
from .utils import get_client


IGNORE = [400, 401, 404, 500]

@task
def change_replicas(index=None, number_of_replicas=1, **kwargs):
    """change_replicas(index=None, number_of_replicas=1, **kwargs)"""
    if "help" in kwargs.keys():
        return help(change_replicas)
    es = get_client(env.elasticsearch_alias)
    body = {"index": {"number_of_replicas": number_of_replicas}}
    res = es.indices.put_settings(body, index=index, ignore=IGNORE, **kwargs)
    jsonprint(res)
    return res

@task
def scan(index=None, doc_type=None, outfile="dump.txt", **kwargs):
    """scan(index=None, doc_type=None, outfile="dump.txt", **kwargs)"""
    if "help" in kwargs.keys():
        return help(scan)

    es = get_client(env.elasticsearch_alias)
    docs = helpers.scan(es, index=index, doc_type=doc_type, ignore=IGNORE, **kwargs)

    success = 0
    with open(outfile, "w") as f:
        for doc in docs:
            f.write(json.dumps(doc, ensure_ascii=False).encode("utf-8"))
            f.write("\n")
            success += 1

    res = {
        "success": success,
        "scan": {
            "host": es.transport.get_connection().host,
            "index": index,
            "doc_type": doc_type,
            "outfile": outfile
        }
    }
    jsonprint(res)
    return res

@task
def bulk(infile="dump.txt", **kwargs):
    """bulk(infile="dump.txt", **kwargs)"""
    if "help" in kwargs.keys():
        return help(bulk)

    try:
        with open(infile, "r") as f:
            actions = []
            indices = {}
            for line in f:
                doc = json.loads(line)
                actions.append(doc)
                index = doc["_index"]
                indices[index] = 1 + indices.get(index, 0)
    except Exception as e:
        abort(e)

    es = get_client(env.elasticsearch_alias)
    success, errors = helpers.bulk(es, actions, ignore=IGNORE, **kwargs)

    res = {
        "success": success, "errors": errors,
        "bulk": {
            "host": es.transport.get_connection().host,
            "indices": indices
        }
    }
    jsonprint(res)
    return res

@task
def reindex(source_index=None, dest_index=None, chunk_size=500, **kwargs):
    """reindex(source_index=None, dest_index=None, chunk_size=500, **kwargs)"""
    if "help" in kwargs.keys():
        return help(reindex)

    source_es = get_client(env.elasticsearch_alias)
    dest_es = get_client(env.elasticsearch_dest_alias)
    dest_index = dest_index or source_index

    try:
        success, errors = helpers.reindex(source_es, source_index=source_index,
            target_client=dest_es, target_index=dest_index,
            chunk_size=chunk_size, **kwargs)
    except Exception as e:
        abort(e)

    res = {
        "success": success, "errors": errors,
        "source": {
            "host": source_es.transport.get_connection().host,
            "index": source_index
        },
        "dest": {
            "host": dest_es.transport.get_connection().host,
            "index": dest_index
        }
    }
    jsonprint(res)
    return res



# coding=utf-8
from fabric.api import task
from .utils import request

@task
def aliases(*args, **kwargs):
    res = request("aliases", "cat", *args, **kwargs)
    print(res)
    return res

@task
def allocation(*args, **kwargs):
    res = request("allocation", "cat", *args, **kwargs)
    print(res)
    return res

@task
def count(*args, **kwargs):
    res = request("count", "cat", *args, **kwargs)
    print(res)
    return res

@task
def fielddata(*args, **kwargs):
    res = request("fielddata", "cat", *args, **kwargs)
    print(res)
    return res

@task
def health(*args, **kwargs):
    res = request("health", "cat", *args, **kwargs)
    print(res)
    return res

@task
def indices(*args, **kwargs):
    res = request("indices", "cat", *args, **kwargs)
    print(res)
    return res

@task
def master(*args, **kwargs):
    res = request("master", "cat", *args, **kwargs)
    print(res)
    return res

@task
def nodeattrs(*args, **kwargs):
    res = request("nodeattrs", "cat", *args, **kwargs)
    print(res)
    return res

@task
def nodes(*args, **kwargs):
    res = request("nodes", "cat", *args, **kwargs)
    print(res)
    return res

@task
def pending_tasks(*args, **kwargs):
    res = request("pending_tasks", "cat", *args, **kwargs)
    print(res)
    return res

@task
def plugins(*args, **kwargs):
    res = request("plugins", "cat", *args, **kwargs)
    print(res)
    return res

@task
def recovery(*args, **kwargs):
    res = request("recovery", "cat", *args, **kwargs)
    print(res)
    return res

@task
def repositories(*args, **kwargs):
    res = request("repositories", "cat", *args, **kwargs)
    print(res)
    return res

@task
def segments(*args, **kwargs):
    res = request("segments", "cat", *args, **kwargs)
    print(res)
    return res

@task
def shards(*args, **kwargs):
    res = request("shards", "cat", *args, **kwargs)
    print(res)
    return res

@task
def snapshots(*args, **kwargs):
    res = request("snapshots", "cat", *args, **kwargs)
    print(res)
    return res

@task
def thread_pool(*args, **kwargs):
    res = request("thread_pool", "cat", *args, **kwargs)
    print(res)
    return res



# coding=utf-8
import os
from distutils.spawn import find_executable
from setuptools import setup, find_packages

from esfabric import __version__

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
    README = readme.read()


if os.path.exists(os.path.join(os.path.dirname(__file__), 'README.txt')):
    with open(os.path.join(os.path.dirname(__file__), 'README.txt')) as readme:
        README = readme.read()

with open(os.path.join(os.path.dirname(__file__), 'requirements.txt')) as requirements:
    REQUIREMENTS = requirements.read().splitlines()

setup(
    name='elasticsearch-fabric',
    version=__version__,
    packages=find_packages(),
    install_requires=REQUIREMENTS,
    license='MIT',
    author='Kunihiko Kido',
    author_email='kunihiko.kido@me.com',
    url='https://github.com/KunihikoKido/elasticsearch-fabric',
    description='This package provides a unified command line interface to Elasticsearch in Fabric.',
    long_description=README,
    platforms=['OS Independent'],
    keywords=['elasticsearch', 'fabric'],
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Programming Language :: Python :: 2.7',
    ],
    include_package_data=True,
)
